<?php

namespace ADELANTE\PayBySquare\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\Encryption\EncryptorInterface;
use Magento\Store\Model\StoreManagerInterface;

/**
 * Class Data
 *
 * @package ADELANTE\PayBySquare\Helper
 */
class Data extends AbstractHelper
{

    /**
     * @var StoreManagerInterface
     */
    protected $_storeManager;

    /**
     * @var EncryptorInterface
     */
    private $encryptor;

    /**
     * Data constructor.
     *
     * @param Context $context
     * @param StoreManagerInterface $storeManager
     * @param EncryptorInterface $encryptor
     */
    public function __construct(
        Context $context,
        StoreManagerInterface $storeManager,
        EncryptorInterface $encryptor
    ) {
        parent::__construct($context);
        $this->_storeManager  = $storeManager;
        $this->encryptor = $encryptor;
    }

    /**
     * @return bool
     */
    public function isEnableConfig(): bool
    {
        return (bool)$this->scopeConfig->getValue('pay_by_square/general/enable', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return string
     */
    public function getUsername(): string
    {
        return (string)$this->scopeConfig->getValue('pay_by_square/general/username', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return string
     */
    public function getPassword(): string
    {
        return (string)$this->scopeConfig->getValue('pay_by_square/general/password', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return string
     */
    public function getBeneficaryName(): string
    {
        return (string)$this->scopeConfig->getValue('pay_by_square/general/beneficary_name', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @param null $currency
     * @return array
     */
    public function getBankAccounts($currency = null): array
    {
        $out = [];
        $accounts = (string)$this->scopeConfig->getValue('pay_by_square/general/bank_accounts', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
        $accounts = explode("\n", $accounts);

        if ($currency === 'CZK') {
            $sortSk = 2;
            $sortCz = 1;
        } elseif ($currency === 'EUR') {
            $sortSk = 1;
            $sortCz = 2;
        }

        foreach ($accounts as $key => $account) {
            $account = explode(':', $account);
            $bic = $account[1] ?: null;
            $account = $account[0];

            $sort = 0;
            if (!empty($currency)) {
                if (strpos($account, 'SK') !== false) {
                    $sort = $sortSk;
                } else if (strpos($account, 'CZ') !== false) {
                    $sort = $sortCz;
                }
            }

            $out[] = [
                'account' => str_replace(' ', '', $account),
                'bic' => $bic,
                'sort' => $sort
            ];
        }

        if (!empty($currency)) {
            usort($out, function($a, $b) {
                return $a['sort'] - $b['sort'];
            });
        }

        return $out;
    }

    /**
     * @return string
     */
    public function getNote(): string
    {
        return (string)$this->scopeConfig->getValue('pay_by_square/general/note', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return array
     */
    public function getActiveFormat(): array
    {
        return explode(',', $this->scopeConfig->getValue('pay_by_square/general/active_format', \Magento\Store\Model\ScopeInterface::SCOPE_STORE));
    }
}
